==> angelscript_2.33.0.zip: sdk/docs/manual/doc_advanced_api.js <==
var doc_advanced_api =
[
    [ "Custom string type", "doc_strings.html", [
      [ "Registering the custom string type", "doc_strings.html#doc_string_register", null ],
      [ "Unicode vs ASCII", "doc_strings.html#doc_strings_1", null ],
      [ "Multiline string literals", "doc_strings.html#doc_string_2", null ],
      [ "Character literals", "doc_strings.html#doc_string_3", null ]
    ] ],
    [ "Custom array type", "doc_arrays.html", null ],
    [ "Garbage collected objects", "doc_gc_object.html", [
      [ "GC support behaviours", "doc_gc_object.html#doc_reg_gcref_1", null ],
      [ "Factory for garbage collection", "doc_gc_object.html#doc_reg_gcref_2", null ],
      [ "Addref and release for garbage collection", "doc_gc_object.html#doc_reg_gcref_3", null ],
      [ "GC behaviours for value types", "doc_gc_object.html#doc_reg_gcref_value", null ],
      [ "Garbage collected objects and multi-threading", "doc_gc_object.html#doc_reg_gcref_4", null ]
    ] ],
    [ "The generic calling convention", "doc_generic.html", [
      [ "Extracting function arguments", "doc_generic.html#doc_generic_1", null ],
      [ "Returning values", "doc_generic.html#doc_generic_2", null ]
    ] ],
    [ "Registering a generic handle type", "doc_adv_generic_handle.html", null ],
    [ "Registering a scoped reference type", "doc_adv_scoped_type.html", null ],
    [ "Registering a single-reference type", "doc_adv_single_ref_type.html", null ],
    [ "Class hierarchies", "doc_adv_class_hierarchy.html", [
      [ "Establishing the relationship", "doc_adv_class_hierarchy.html#doc_adv_class_hierarchy_1", null ],
      [ "Inherited methods and properties", "doc_adv_class_hierarchy.html#doc_adv_class_hierarchy_2", null ]
    ] ],
    [ "The variable parameter type", "doc_adv_var_type.html", null ],
    [ "Template types", "doc_adv_template.html", [
      [ "Registering the template type", "doc_adv_template.html#doc_adv_template_1", [
        [ "On subtype replacement for template instances", "doc_adv_template.html#doc_adv_template_1_1", null ]
      ] ],
      [ "Validating template instantiations at compile time", "doc_adv_template.html#doc_adv_template_4", null ],
      [ "Template specializations", "doc_adv_template.html#doc_adv_template_2", null ]
    ] ],
    [ "Weak references", "doc_adv_weakref.html", null ],
    [ "C++ exceptions and longjmp", "doc_cpp_exceptions.html", [
      [ "Exceptions", "doc_cpp_exceptions.html#doc_cpp_exceptions_1", null ],
      [ "longjmp", "doc_cpp_exceptions.html#doc_cpp_exceptions_2", null ]
    ] ]
];

==> angelscript_2.37.0.zip: sdk/docs/manual/doc_advanced_api.js <==
var doc_advanced_api =
[
    [ "Custom string type", "doc_strings.html", [
      [ "Registering the custom string type", "doc_strings.html#doc_string_register", null ],
      [ "Unicode vs ASCII", "doc_strings.html#doc_strings_1", null ],
      [ "Multiline string literals", "doc_strings.html#doc_string_2", null ],
      [ "Character literals", "doc_strings.html#doc_string_3", null ]
    ] ],
    [ "Custom array type", "doc_arrays.html", null ],
    [ "Garbage collected objects", "doc_gc_object.html", [
      [ "GC support behaviours", "doc_gc_object.html#doc_reg_gcref_1", null ],
      [ "Factory for garbage collection", "doc_gc_object.html#doc_reg_gcref_2", null ],
      [ "Addref and release for garbage collection", "doc_gc_object.html#doc_reg_gcref_3", null ],
      [ "GC behaviours for value types", "doc_gc_object.html#doc_reg_gcref_value", null ],
      [ "Garbage collected objects and multi-threading", "doc_gc_object.html#doc_reg_gcref_4", null ]
    ] ],
    [ "The generic calling convention", "doc_generic.html", [
      [ "Extracting function arguments", "doc_generic.html#doc_generic_1", null ],
      [ "Returning values", "doc_generic.html#doc_generic_2", null ]
    ] ],
    [ "Registering a generic handle type", "doc_adv_generic_handle.html", null ],
    [ "Registering a scoped reference type", "doc_adv_scoped_type.html", null ],
    [ "Registering a single-reference type", "doc_adv_single_ref_type.html", null ],
    [ "Class hierarchies", "doc_adv_class_hierarchy.html", [
      [ "Establishing the relationship", "doc_adv_class_hierarchy.html#doc_adv_class_hierarchy_1", null ],
      [ "Inherited methods and properties", "doc_adv_class_hierarchy.html#doc_adv_class_hierarchy_2", null ]
    ] ],
    [ "The variable parameter type", "doc_adv_var_type.html", [
      [ "Variable conversion operators", "doc_adv_var_type.html#doc_adv_var_type_1", null ]
    ] ],
    [ "Template types", "doc_adv_template.html", [
      [ "Registering the template type", "doc_adv_template.html#doc_adv_template_1", [
        [ "On subtype replacement for template instances", "doc_adv_template.html#doc_adv_template_1_1", null ]
      ] ],
      [ "Validating template instantiations at compile time", "doc_adv_template.html#doc_adv_template_4", null ],
      [ "Template specializations", "doc_adv_template.html#doc_adv_template_2", null ]
    ] ],
    [ "Weak references", "doc_adv_weakref.html", null ],
    [ "C++ exceptions and longjmp", "doc_cpp_exceptions.html", [
      [ "Exceptions", "doc_cpp_exceptions.html#doc_cpp_exceptions_1", null ],
      [ "longjmp", "doc_cpp_exceptions.html#doc_cpp_exceptions_2", null ]
    ] ]
];
